==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/javascript2.editor/src/org/netbeans/modules/javascript2/editor/Utils.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.javascript2.editor;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import org.netbeans.modules.javascript2.editor.model.Type;
import org.netbeans.modules.javascript2.editor.model.impl.ModelUtils;

/**
 *
 * @author Petr Pisl
 */
public class Utils {
    
    /**
     * Converts the types names to the display names. It can return empty collection
     * if the all types in input refers anonymous objects or functions.
     * @param types collection of types 
     * @return collection of display names
     */
    public static Collection<String> getDisplayNames(Collection<? extends Type> types) {
        List<String> displayNames = new ArrayList<String>(types.size());
        for (Type type : types) {
            String displayName = type.getDisplayName();
            if (!displayName.isEmpty()) {
                displayNames.add(displayName);
            }
        }
        Collections.sort(displayNames);
        return displayNames;
    }
    
    /**
     * Converts the fully qualified names to the display names. It can return empty collection
     * if the all types in input refers anonymous objects or functions.
     * @param types collection of fully qualified names
     * @return collection of display names
     */
    public static Collection<String> getDisplayNamesFromStrings(Collection<String> fqns) {
        List<String> displayNames = new ArrayList<String>(fqns.size());
        for (String fqn : fqns) {
            String displayName = ModelUtils.getDisplayName(fqn);
            if (displayName.length() != 0) {
                displayNames.add(displayName);
            }
        }
        return displayNames;
    }
}

==> netbeans_8.1+dfsg2.orig.tar.xz: netbeans-8.1/javascript2.editor/src/org/netbeans/modules/javascript2/editor/Utils.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.javascript2.editor;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import org.netbeans.modules.javascript2.editor.model.Type;
import org.netbeans.modules.javascript2.editor.model.impl.ModelExtender;
import org.netbeans.modules.javascript2.editor.model.impl.ModelUtils;
import org.netbeans.modules.javascript2.editor.spi.model.TypeDisplayNameConvertor;

/**
 *
 * @author Petr Pisl
 */
public class Utils {
    
    /**
     * Converts the types names to the display names. It can return empty collection
     * if the all types in input refers anonymous objects or functions.
     * @param types collection of types 
     * @return collection of display names
     */
    public static Collection<String> getDisplayNames(Collection<? extends Type> types) {
        List<String> displayNames = new ArrayList<String>(types.size());
        List<TypeDisplayNameConvertor> convertors = ModelExtender.getDefault().getTypeDisplayNameConvertors();
        for (Type type : types) {
            String displayName = null;
            for (TypeDisplayNameConvertor convertor: convertors) {
                displayName = convertor.getDisplayName(type);
                if (displayName != null && !displayName.isEmpty() && !displayName.equals(type.getType())) {
                    break;
                }
            }
            if (displayName == null || displayName.isEmpty() || displayName.equals(type.getType())) {
                displayName = ModelUtils.getDisplayName(type.getType());
            }
            if (displayName != null && !displayName.isEmpty() && !displayNames.contains(displayName)) {
                displayNames.add(displayName);
            }
        }
        Collections.sort(displayNames);
        return displayNames;
    }
    
    public static String getDisplayName(Type type) {
        List<TypeDisplayNameConvertor> convertors = ModelExtender.getDefault().getTypeDisplayNameConvertors();
        String displayName = null;
        for (TypeDisplayNameConvertor convertor: convertors) {
            displayName = convertor.getDisplayName(type);
            if (displayName != null && !displayName.isEmpty() && !displayName.equals(type.getType())) {
                break;
            }
        }
        if (displayName == null || displayName.isEmpty() || displayName.equals(type.getType())) {
            displayName = ModelUtils.getDisplayName(type.getType());
        }
        return displayName;
    }
    
    /**
     * Converts the fully qualified names to the display names. It can return empty collection
     * if the all types in input refers anonymous objects or functions.
     * @param types collection of fully qualified names
     * @return collection of display names
     */
    public static Collection<String> getDisplayNamesFromStrings(Collection<String> fqns) {
        List<String> displayNames = new ArrayList<String>(fqns.size());
        for (String fqn : fqns) {
            String displayName = ModelUtils.getDisplayName(fqn);
            if (displayName.length() != 0) {
                displayNames.add(displayName);
            }
        }
        return displayNames;
    }
}
